==> teradataml-17.20.0.0-py3-none-any.whl: teradataml/data/docs/sqle/docs_17_20/RandomProjectionMinComponents.py <==
def RandomProjectionMinComponents(data=None, target_columns=None, epsilon=0.1,  **generic_arguments):
    """
    DESCRIPTION:
        The RandomProjectionMinComponents() function calculates
        "num_components" required for applying RandomProjection on the given
        dataset for the specified "epsilon" (distortion) parameter value. The
        function estimates the minimum value of the "num_components" argument in
        the RandomProjectionFit() function for a given dataset. The function
        uses the Johnson-Lindenstrauss Lemma algorithm to calculate the value.

    PARAMETERS:
        data:
            Required Argument.
            Specifies the input teradataml DataFrame.
            Types: teradataml DataFrame
            
        target_columns:
            Required Argument.
            Specifies the name(s) of the column(s) in "data" for random projection.
            Types: str OR list of Strings (str)
            
        epsilon:
            Optional Argument.
            Specifies a value to control distortion introduced while
            projecting the data to a lower dimension. The amount of
            distortion increases if you increase the value. Allowed
            Value is between 0 and 1.
            Default Value: 0.1
            Types: float
            
        **generic_arguments:
            Specifies the generic keyword arguments SQLE functions accept.
            Below are the generic keyword arguments:
                persist:
                    Optional Argument.
                    Specifies whether to persist the results of the
                    function in a table or not. When set to True,
                    results are persisted in a table; otherwise,
                    results are garbage collected at the end of the
                    session.
                    Default Value: False
                    Types: bool
                    
                volatile:
                    Optional Argument.
                    Specifies whether to put the results of the
                    function in a volatile table or not. When set to
                    True, results are stored in a volatile table,
                    otherwise not.
                    Default Value: False
                    Types: bool
                     
            Function allows the user to partition, hash, order or local
            order the input data. These generic arguments are available
            for each argument that accepts teradataml DataFrame as
            input and can be accessed as:
                * "<input_data_arg_name>_partition_column" accepts str or
                      list of str (Strings)
                * "<input_data_arg_name>_hash_column" accepts str or list
                      of str (Strings)
                * "<input_data_arg_name>_order_column" accepts str or list
                      of str (Strings)
                * "local_order_<input_data_arg_name>" accepts boolean
            Note:
                These generic arguments are supported by teradataml if
                the underlying SQL Engine function supports, else an
                exception is raised.
        
    RETURNS:
        Instance of RandomProjectionMinComponents.
        Output teradataml DataFrames can be accessed using attribute
        references, such as RandomProjectionMinComponentsObj.<attribute_name>.
        Output teradataml DataFrame attribute name is:
            result
        
        
    RAISES:
        TeradataMlException, TypeError, ValueError
        
        
    EXAMPLES:
        # Notes:
        #     1. Get the connection to Vantage, before importing the
        #        function in user space.
        #     2. User can import the function, if it is available on
        #        Vantage user is connected to.
        #     3. To check the list of analytic functions available on
        #        Vantage user connected to, use
        #        "display_analytic_functions()".
            
        # Load the example data.
        load_example_data("teradataml", ["stock_movement"])
            
        # Create teradataml DataFrame objects.
        stock_movement = DataFrame.from_table("stock_movement")
            
        # Check the list of available analytic functions.
        display_analytic_functions()
            
        # Import function RandomProjectionMinComponents.
        from teradataml import RandomProjectionMinComponents
            
        # Example 1 : Calculate the minimum number of components required
        #             for applying RandomProjectionFit().
        RandomProjectionMinComponents_out = RandomProjectionMinComponents(data = stock_movement,
                                                                          target_columns = "1:")
            
        # Print the result DataFrame.
        print(RandomProjectionMinComponents_out)
        
    """

==> teradataml-17.20.0.3-py3-none-any.whl: teradataml/data/docs/sqle/docs_17_20/RandomProjectionMinComponents.py <==
def RandomProjectionMinComponents(data=None, target_columns=None, epsilon=0.1,  **generic_arguments):
    """
    DESCRIPTION:
        The RandomProjectionMinComponents() function calculates
        "num_components" required for applying RandomProjection on the given
        dataset for the specified "epsilon" (distortion) parameter value. The
        function estimates the minimum value of the "num_components" argument in
        the RandomProjectionFit() function for a given dataset. The function
        uses the Johnson-Lindenstrauss Lemma algorithm to calculate the value.

    PARAMETERS:
        data:
            Required Argument.
            Specifies the input teradataml DataFrame.
            Types: teradataml DataFrame
            
        target_columns:
            Required Argument.
            Specifies the name(s) of the column(s) in "data" for random projection.
            Types: str OR list of Strings (str)
            
        epsilon:
            Optional Argument.
            Specifies a value to control distortion introduced while
            projecting the data to a lower dimension. The amount of
            distortion increases if you increase the value. Allowed
            Value is between 0 and 1.
            Default Value: 0.1
            Types: float
            
        **generic_arguments:
            Specifies the generic keyword arguments SQLE functions accept.
            Below are the generic keyword arguments:
                persist:
                    Optional Argument.
                    Specifies whether to persist the results of the
                    function in a table or not. When set to True,
                    results are persisted in a table; otherwise,
                    results are garbage collected at the end of the
                    session.
                    Default Value: False
                    Types: bool
                    
                volatile:
                    Optional Argument.
                    Specifies whether to put the results of the
                    function in a volatile table or not. When set to
                    True, results are stored in a volatile table,
                    otherwise not.
                    Default Value: False
                    Types: bool
                     
            Function allows the user to partition, hash, order or local
            order the input data. These generic arguments are available
            for each argument that accepts teradataml DataFrame as
            input and can be accessed as:
                * "<input_data_arg_name>_partition_column" accepts str or
                      list of str (Strings)
                * "<input_data_arg_name>_hash_column" accepts str or list
                      of str (Strings)
                * "<input_data_arg_name>_order_column" accepts str or list
                      of str (Strings)
                * "local_order_<input_data_arg_name>" accepts boolean
            Note:
                These generic arguments are supported by teradataml if
                the underlying SQL Engine function supports, else an
                exception is raised.
        
    RETURNS:
        Instance of RandomProjectionMinComponents.
        Output teradataml DataFrames can be accessed using attribute
        references, such as RandomProjectionMinComponentsObj.<attribute_name>.
        Output teradataml DataFrame attribute name is:
            result
        
        
    RAISES:
        TeradataMlException, TypeError, ValueError
        
        
    EXAMPLES:
        # Notes:
        #     1. Get the connection to Vantage to execute the function.
        #     2. One must import the required functions mentioned in
        #        the example from teradataml.
        #     3. Function will raise error if not supported on the Vantage
        #        user is connected to.
            
        # Load the example data.
        load_example_data("teradataml", ["stock_movement"])
            
        # Create teradataml DataFrame objects.
        stock_movement = DataFrame.from_table("stock_movement")
            
        # Check the list of available analytic functions.
        display_analytic_functions()
            
        # Example 1 : Calculate the minimum number of components required
        #             for applying RandomProjectionFit().
        RandomProjectionMinComponents_out = RandomProjectionMinComponents(data = stock_movement,
                                                                          target_columns = "1:")
            
        # Print the result DataFrame.
        print(RandomProjectionMinComponents_out)
        
    """
